pub enum DocumentCommands {
List {
folder: Option<String>,
doc_type: Option<String>,
},
Search {
query: String,
},
Exists {
amount: f64,
date: String,
contact: Option<String>,
},
}Variants
List
List documents in a folder or of a given type.
Search
Search documents by a query string.
Exists
Check if an invoice exists in the archive (by amount, date, and optional contact).