AccountingClient

Struct AccountingClient 

pub struct AccountingClient { /* private fields */ }
Client for the Yuki Accounting SOAP service.

Implementations

Source

impl AccountingClient

pub fn new() -> Self

pub async fn authenticate(&mut self, api_key: &str) -> Result<String, YukiError>

Authenticate with the Yuki API and store the session ID.

pub async fn administrations(&self) -> Result<Vec<Administration>, YukiError>

List all administrations accessible with the current session.

pub async fn set_current_domain( &mut self, domain_id: &str, ) -> Result<(), YukiError>

Set the active domain (administration) for subsequent calls.

pub async fn gl_account_balance( &self, administration_id: &str, gl_account_code: &str, transaction_date: &str, ) -> Result<String, YukiError>

Retrieve the balance of a GL account as of a given date.

pub async fn gl_account_transactions( &self, administration_id: &str, gl_account_code: &str, start_date: &str, end_date: &str, ) -> Result<String, YukiError>

Retrieve transactions for a GL account over a date range.

pub async fn outstanding_debtor_items( &self, administration_id: &str, ) -> Result<Vec<OutstandingItem>, YukiError>

Retrieve outstanding debtor items.

pub async fn outstanding_debtor_items_by_date( &self, administration_id: &str, start_date: &str, end_date: &str, ) -> Result<Vec<OutstandingItem>, YukiError>

Retrieve outstanding debtor items filtered by date range.

pub async fn outstanding_creditor_items( &self, administration_id: &str, ) -> Result<Vec<OutstandingItem>, YukiError>

Retrieve outstanding creditor items.

pub async fn outstanding_creditor_items_by_date( &self, administration_id: &str, start_date: &str, end_date: &str, ) -> Result<Vec<OutstandingItem>, YukiError>

Retrieve outstanding creditor items filtered by date range.

pub async fn gl_account_transactions_and_contact( &self, administration_id: &str, gl_account_code: &str, start_date: &str, end_date: &str, ) -> Result<Vec<GlTransactionWithContact>, YukiError>

Retrieve transactions for a GL account with contact info over a date range.

pub async fn net_revenue( &self, administration_id: &str, start_date: &str, end_date: &str, ) -> Result<String, YukiError>

Retrieve net revenue for a date range.

pub async fn check_outstanding_item_admin( &self, administration_id: &str, reference: &str, ) -> Result<String, YukiError>

Check if a specific reference is still outstanding in an administration.

pub fn parse_gl_transactions(xml: &str) -> Result<Vec<GlTransaction>, YukiError>

Parse a GLAccountTransactions SOAP response into a list of GlTransaction values.

Each GLAccountTransaction element carries an ID attribute and child elements Date, Description, Amount, and GLAccountCode.

pub fn parse_gl_transactions_with_contact( xml: &str, ) -> Result<Vec<GlTransactionWithContact>, YukiError>

Parse a GLAccountTransactionsAndContact SOAP response.

Like parse_gl_transactions but also captures Contact/ContactName.

pub fn parse_administrations( xml: &str, ) -> Result<Vec<Administration>, YukiError>

Parse an Administrations SOAP response into a list of Administration values.

The Yuki API returns Administration elements with the ID as an XML attribute and Name as a child element: <Administration ID="uuid"><Name>Company</Name>...</Administration>

pub fn parse_outstanding_items( xml: &str, result_tag: &str, ) -> Result<Vec<OutstandingItem>, YukiError>

Parse an outstanding items SOAP response into a list of OutstandingItem values.

The result_tag identifies the wrapper element in the response (e.g. "OutstandingDebtorItemsResult").